@@ -79,6 +79,8 @@ var p =  new java.util.Properties ();
 p.put ("PATH_KEY", ".PATH");
 p.put ("PATH_SEPARATOR", J.adapter.smarter.SmarterJmolAdapter.PATH_SEPARATOR);
 this.setInfo ("properties", p);
+var modelIndex = (reader == null ? null : reader.htParams.get ("appendToModelIndex"));
+if (modelIndex != null) this.setInfo ("appendToModelIndex", modelIndex);
 if (array != null) {
 var n = 0;
 this.readerList =  new JU.Lst ();
