@@ -80,8 +80,6 @@ var isOK = true;
 if (this.vwr.ms !== this.lastModelSet) {
 this.lastModelSet = this.vwr.ms;
 isOK = false;
-} else if (this.currentModelIndex == -1 || this.currentModelIndex != this.vwr.am.cmi) {
-isOK = false;
 }this.currentModelIndex = Math.max (this.vwr.am.cmi, 0);
 this.iatom0 = this.vwr.ms.am[this.currentModelIndex].firstAtomIndex;
 if (!isOK) {
@@ -407,9 +405,7 @@ return false;
 Clazz.defineMethod (c$, "getHoverLabel", 
  function (atomIndex) {
 var state = this.getMKState ();
-if (state != 1 && atomIndex >= 0 && !this.vwr.ms.isAtomInLastModel (atomIndex)) {
-return "Only atoms in the last model may be edited.";
-}var msg = null;
+var msg = null;
 switch (state) {
 case 1:
 if (this.symop == null) this.symop = Integer.$valueOf (1);
