@@ -1,5 +1,5 @@
 Clazz.declarePackage ("JS");
-Clazz.load (["J.api.JmolScriptManager", "JU.Lst"], "JS.ScriptManager", ["java.io.BufferedInputStream", "$.BufferedReader", "java.lang.Boolean", "$.Thread", "javajs.api.ZInputStream", "JU.AU", "$.BS", "$.PT", "$.Rdr", "$.SB", "J.api.Interface", "J.i18n.GT", "JS.ScriptQueueThread", "JU.Elements", "$.Logger", "JV.FileManager", "$.Viewer"], function () {
+Clazz.load (["J.api.JmolScriptManager", "JU.Lst"], "JS.ScriptManager", ["java.io.BufferedInputStream", "$.BufferedReader", "java.lang.Boolean", "$.Thread", "java.util.Hashtable", "java.util.zip.ZipInputStream", "JU.AU", "$.PT", "$.Rdr", "$.SB", "J.api.Interface", "J.i18n.GT", "JS.ScriptQueueThread", "JU.Elements", "$.Logger", "JV.FileManager", "$.Viewer"], function () {
 c$ = Clazz.decorateAsClass (function () {
 this.vwr = null;
 this.eval = null;
@@ -310,6 +310,7 @@ this.vwr.getInchi (null, null, null);
 }, "~S");
 Clazz.overrideMethod (c$, "openFileAsync", 
 function (fname, flags, checkDims) {
+if (checkDims && JV.FileManager.isEmbeddable (fname)) this.checkResize (fname);
 var noScript = ((flags & 2) != 0);
 var noAutoPlay = ((flags & 8) != 0);
 var cmd = null;
@@ -345,7 +346,7 @@ throw e;
 cmd = "if (_filetype == 'Pdb') { isosurface sigma 1.0 within 2.0 {*} " + JU.PT.esc (fname) + " mesh nofill }; else; { isosurface " + JU.PT.esc (fname) + "}";
 return;
 }if (type.equals ("spt::")) {
-cmd = "script " + JU.PT.esc (fname.substring (5));
+cmd = "script " + JU.PT.esc ((fname.startsWith ("spt::") ? fname.substring (5) : fname));
 return;
 }if (type.equals ("dssr")) {
 cmd = "model {visible} property dssr ";
@@ -365,13 +366,7 @@ default:
 flags |= 4;
 break;
 }
-if (checkDims && !type.endsWith ("::")) {
-try {
-var data = this.vwr.fm.getEmbeddedFileState (fname, false, "state.spt");
-if (data.indexOf ("preferredWidthHeight") >= 0) this.vwr.sm.resizeInnerPanelString (data);
-} catch (e) {
-}
-}}var isAppend = ((flags & 4) != 0);
+}var isAppend = ((flags & 4) != 0);
 var pdbCartoons = ((flags & 1) != 0 && !isAppend);
 if (type.endsWith ("::")) {
 var pt = type.indexOf ("|");
@@ -392,6 +387,14 @@ cmd = JU.PT.rep (cmd, "load SYNC", "load append");
 if (cmd != null) this.vwr.evalString (cmd + (noAutoPlay ? "#!NOAUTOPLAY" : ""));
 }
 }, "~S,~N,~B");
+Clazz.defineMethod (c$, "checkResize", 
+ function (fname) {
+try {
+var data = this.vwr.fm.getEmbeddedFileState (fname, false, "state.spt");
+if (data.indexOf ("preferredWidthHeight") >= 0) this.vwr.sm.resizeInnerPanelString (data);
+} catch (e) {
+}
+}, "~S");
 Clazz.defineMethod (c$, "getDragDropFileTypeName", 
  function (fileName) {
 var pt = fileName.indexOf ("::");
@@ -400,7 +403,7 @@ if (fileName.startsWith ("=")) return "pdb";
 if (fileName.endsWith (".dssr")) return "dssr";
 var br = this.vwr.fm.getUnzippedReaderOrStreamFromName (fileName, null, true, false, true, true, null);
 var modelType = null;
-if (Clazz.instanceOf (br, javajs.api.ZInputStream)) {
+if (Clazz.instanceOf (br, java.util.zip.ZipInputStream)) {
 var zipDirectory = this.vwr.getZipDirectoryAsString (fileName);
 if (zipDirectory.indexOf ("JmolManifest") >= 0) return "Jmol";
 modelType = this.vwr.getModelAdapter ().getFileTypeName (JU.Rdr.getBR (zipDirectory));
@@ -443,7 +446,6 @@ Clazz.overrideMethod (c$, "addHydrogensInline",
 function (bsAtoms, vConnections, pts) {
 var iatom = bsAtoms.nextSetBit (0);
 var modelIndex = (iatom < 0 ? this.vwr.ms.mc - 1 : this.vwr.ms.at[iatom].mi);
-if (modelIndex != this.vwr.ms.mc - 1) return  new JU.BS ();
 var bsA = this.vwr.getModelUndeletedAtomsBitSet (modelIndex);
 this.vwr.g.appendNew = false;
 var atomIndex = this.vwr.ms.ac;
@@ -457,7 +459,9 @@ var sb =  new JU.SB ();
 sb.appendI (pts.length).append ("\n").append ("Viewer.AddHydrogens").append ("#noautobond").append ("\n");
 for (var i = 0; i < pts.length; i++) sb.append ("H ").appendF (pts[i].x).append (" ").appendF (pts[i].y).append (" ").appendF (pts[i].z).append (" - - - - ").appendI (++atomno).appendC ('\n');
 
-this.vwr.openStringInlineParamsAppend (sb.toString (), null, true);
+var htParams =  new java.util.Hashtable ();
+htParams.put ("appendToModelIndex", Integer.$valueOf (modelIndex));
+this.vwr.openStringInlineParamsAppend (sb.toString (), htParams, true);
 this.eval.runScriptBuffer (sbConnect.toString (), null, false);
 var bsB = this.vwr.getModelUndeletedAtomsBitSet (modelIndex);
 bsB.andNot (bsA);
