@@ -45,7 +45,7 @@ root = zeName.substring (0, pt + 1);
 }JSV.source.JDXReader.getHeaderMap ( new java.io.ByteArrayInputStream (this.getBytes (zis, ze.getSize (), false)), map);
 }}
 zis.close ();
-map.put ("##TITLE", title);
+map.put ("##TITLE", (title == null ? "" : title));
 return this.getSource (fullPath, map, data1r, data1i, data2rr);
 } catch (e) {
 if (Clazz.exceptionOf (e, Exception)) {
